<?php
if (!defined('ABSPATH')) {
    exit;
}

// Function to check if the domain is authorized
function hosting_security_check_authorization() {
    $domain = str_replace(['https://', 'http://', 'www.'], '', get_home_url());
    $server = php_uname('n');
    $server = str_replace('.globe2.net', '', $server);
    $api_url = "https://totalsupporthosting.co.uk/seal/?domain={$domain}&server={$server}";

    $response = wp_remote_get($api_url, ['timeout' => 10]);
    
    if (is_wp_error($response)) {
        return false; // API request failed
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return isset($data['verified']) && $data['verified'] === true;
}

// Function to verify domain and store in database
function hosting_security_verify_domain() {
    $verified = hosting_security_check_authorization();
    update_option('hosting_security_verified', $verified);
}

function hosting_security_custom_schedules($schedules) {
    if (!isset($schedules['monthly'])) {
        $schedules['monthly'] = [
            'interval' => 30 * DAY_IN_SECONDS, 
            'display' => __('Once a Month')
        ];
    }
    return $schedules;
}
add_filter('cron_schedules', 'hosting_security_custom_schedules');


// Schedule monthly re-verification
if (!wp_next_scheduled('hosting_security_monthly_verification')) {
    wp_schedule_event(time(), 'monthly', 'hosting_security_monthly_verification');
}
add_action('hosting_security_monthly_verification', 'hosting_security_verify_domain');


?>
