<?php
if (!defined('ABSPATH')) {
    exit;
}

// Function to get all available features & descriptions
function hosting_security_get_available_features() {
    $feature_files = glob(plugin_dir_path(__FILE__) . 'features/*.php');
    $features = [];

    foreach ($feature_files as $file) {
        $feature_key = basename($file, '.php');
        $formatted_name = ucwords(str_replace('-', ' ', $feature_key));
        $description = hosting_security_extract_feature_description($file);
        $features[$feature_key] = [
            'name' => $formatted_name,
            'description' => $description
        ];
    }

    return $features;
}

// Function to extract feature description from a file
function hosting_security_extract_feature_description($file_path) {
    $contents = file_get_contents($file_path);
    if (preg_match('/@description\s+(.+)/', $contents, $matches)) {
        return trim($matches[1]);
    }
    return 'No description available.';
}

// Function to check if the current user’s IP is whitelisted
function hosting_security_is_ip_whitelisted() {
    $settings = hosting_security_get_settings();
    
    // Get the user's IP
    $user_ip = $_SERVER['REMOTE_ADDR'];

    // Internal whitelist (Always Trusted IPs)
    $internal_whitelist = ['82.30.1.144'];

    // Get user-defined whitelist and sanitize input
    $user_whitelist = [];
    if (!empty($settings['whitelist-ips'])) {
        $user_whitelist = array_filter(array_map('trim', explode(',', $settings['whitelist-ips'])));
    }

    // Merge both lists
    $whitelisted_ips = array_merge($internal_whitelist, $user_whitelist);

    return in_array($user_ip, $whitelisted_ips);
}

// Check if domain is verified
$verified = get_option('hosting_security_verified', false);

// If the domain is NOT verified, disable all security features
if (!$verified) {
    return;
}

// Fetch settings **once** for efficiency
$settings = hosting_security_get_settings();

// If user IP is not whitelisted, load security features
if (!hosting_security_is_ip_whitelisted()) {

    // Load all features **before** WordPress authentication runs
    foreach (hosting_security_get_available_features() as $feature_key => $feature_data) {
        if (!empty($settings[$feature_key])) {
            include_once plugin_dir_path(__FILE__) . "features/{$feature_key}.php";
        }
    }
}
?>
