<?php
/**
 * @description Restricts admin logins to specific hours.
 */
if (!defined('ABSPATH')) {
    exit;
}

// Get settings
$settings = hosting_security_get_settings();

// Apply feature only if enabled
if (!empty($settings['restrict-admin-login-hours'])) {
    function hosting_security_restrict_admin_hours($user, $username, $password) {
        if (is_wp_error($user)) {
            return $user; // Return existing error if present
        }

        // Check if the user is an admin
        if (isset($user->roles) && in_array('administrator', (array) $user->roles)) {
            // Get current time in 24-hour format
            $current_time = current_time('H:i');
            $start_time = $settings['admin-login-start-time'];
            $end_time = $settings['admin-login-end-time'];

            // Block login if outside allowed hours
            if ($current_time < $start_time || $current_time > $end_time) {
                return new WP_Error('restricted_time', __('Admin logins are restricted to specific hours.'));
            }
        }
        return $user;
    }
    add_filter('authenticate', 'hosting_security_restrict_admin_hours', 10, 3); // Higher priority (runs before obfuscation)
}
?>
